@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Result;
 
-$WWW::Google::CustomSearch::Result::VERSION   = '0.32';
+$WWW::Google::CustomSearch::Result::VERSION   = '0.33';
 $WWW::Google::CustomSearch::Result::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WWW::Google::CustomSearch::Result - Placeholder for Google JSON/Atom Custom Sear
 
 =head1 VERSION
 
-Version 0.32
+Version 0.33
 
 =cut
 
@@ -227,7 +227,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/WWW-Google-CustomSearch>
+L<https://github.com/manwar/WWW-Google-CustomSearch>
 
 =head1 CONTRIBUTORS
 
